@@ -1,29 +1,33 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'ar',
+ 'AR': 'gcc-ar',
  'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/python-inst/bin',
- 'BINLIBDEST': '/python-inst/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
+ 'BINLIBDEST': '/python-inst/lib/python3.9',
+ 'BLDLIBRARY': '-L. -lpython3.9',
  'BLDSHARED': '/usr/bin/ccache gcc '
-              '-I/tinderbox/buildslave/build/workdir/UnpackedTarball/expat/lib '
+              '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+              '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
               '-pthread -shared '
-              '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
-              '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary',
+              '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
+              '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+              '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
+              '-flto=jobserver -fuse-linker-plugin -O2',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
  'CC': '/usr/bin/ccache gcc '
-       '-I/tinderbox/buildslave/build/workdir/UnpackedTarball/expat/lib '
-       '-pthread',
+       '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+       '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall',
  'CFLAGSFORSHARED': '-fPIC',
@@ -35,35 +39,45 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
-                      '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary',
+ 'CONFIGURE_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
+                      '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+                      '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
+                      '-flto=jobserver -fuse-linker-plugin -O2',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/python-inst' '--with-system-expat' "
+ 'CONFIG_ARGS': "'--build=x86_64-pc-linux-gnu' '--host=x86_64-pc-linux-gnu' "
+                "'--prefix=/python-inst' '--with-system-expat' "
                 "'--enable-shared' "
-                "'--with-openssl=/tinderbox/buildslave/build/workdir/UnpackedTarball/openssl' "
-                "'PKG_CONFIG_LIBDIR=/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu' "
+                "'--with-openssl=/home/buildslave/build/workdir/UnpackedTarball/openssl' "
+                "'PKG_CONFIG_LIBDIR=/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu' "
                 "'CC=/usr/bin/ccache gcc "
-                "-I/tinderbox/buildslave/build/workdir/UnpackedTarball/expat/lib' "
+                '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+                "-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib' "
                 "'CFLAGS=   ' "
-                "'LDFLAGS=-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs "
-                "-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary' "
-                "'PKG_CONFIG=/usr/bin/pkg-config'",
+                "'LDFLAGS=-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs "
+                '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+                '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
+                "-flto=jobserver -fuse-linker-plugin -O2' "
+                "'build_alias=x86_64-pc-linux-gnu' "
+                "'host_alias=x86_64-pc-linux-gnu' "
+                "'PKG_CONFIG=/usr/bin/pkg-config' "
+                "'PKG_CONFIG_PATH=/opt/rh/gcc-toolset-12/root/usr/lib64/pkgconfig:/opt/rh/gcc-toolset-12/root/usr/lib64/pkgconfig'",
  'CONFINCLUDEDIR': '/python-inst/include',
- 'CONFINCLUDEPY': '/python-inst/include/python3.8',
+ 'CONFINCLUDEPY': '/python-inst/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tinderbox/buildslave/build/workdir/UnpackedTarball/python3/coverage.info',
- 'COVERAGE_REPORT': '/tinderbox/buildslave/build/workdir/UnpackedTarball/python3/lcov-report',
+ 'COVERAGE_INFO': '/home/buildslave/build/workdir/UnpackedTarball/python3/coverage.info',
+ 'COVERAGE_REPORT': '/home/buildslave/build/workdir/UnpackedTarball/python3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
  'CXX': '/usr/bin/ccache g++ -pthread',
- 'DESTDIRS': '/python-inst /python-inst/lib /python-inst/lib/python3.8 '
-             '/python-inst/lib/python3.8/lib-dynload',
- 'DESTLIB': '/python-inst/lib/python3.8',
+ 'DESTDIRS': '/python-inst /python-inst/lib /python-inst/lib/python3.9 '
+             '/python-inst/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/python-inst/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/python-inst/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/python-inst/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -85,14 +99,15 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'upgrade',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-3.8.so',
+ 'EXT_SUFFIX': '.cpython-3.9.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -130,7 +145,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
- 'HAVE_COPY_FILE_RANGE': 0,
+ 'HAVE_COPY_FILE_RANGE': 1,
  'HAVE_CRYPT_H': 1,
  'HAVE_CRYPT_R': 1,
  'HAVE_CTERMID': 1,
@@ -170,6 +185,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
@@ -178,7 +194,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
  'HAVE_EXECV': 1,
- 'HAVE_EXPLICIT_BZERO': 0,
+ 'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
  'HAVE_EXPM1': 1,
  'HAVE_FACCESSAT': 1,
@@ -217,7 +233,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 0,
+ 'HAVE_GETENTROPY': 1,
  'HAVE_GETGRGID_R': 1,
  'HAVE_GETGRNAM_R': 1,
  'HAVE_GETGROUPLIST': 1,
@@ -240,14 +256,13 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETPWENT': 1,
  'HAVE_GETPWNAM_R': 1,
  'HAVE_GETPWUID_R': 1,
- 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM': 1,
  'HAVE_GETRANDOM_SYSCALL': 1,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -279,18 +294,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 0,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
- 'HAVE_LINUX_QRTR_H': 0,
+ 'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -300,7 +320,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMFD_CREATE': 0,
+ 'HAVE_MEMFD_CREATE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -316,6 +336,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -330,7 +351,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_POSIX_SPAWNP': 1,
  'HAVE_PREAD': 1,
  'HAVE_PREADV': 1,
- 'HAVE_PREADV2': 0,
+ 'HAVE_PREADV2': 1,
  'HAVE_PRLIMIT': 1,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
@@ -342,10 +363,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
- 'HAVE_PWRITEV2': 0,
+ 'HAVE_PWRITEV2': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -367,6 +387,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 0,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -439,6 +460,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -457,7 +479,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
- 'HAVE_SYS_RANDOM_H': 0,
+ 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 1,
@@ -494,7 +516,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -521,50 +542,57 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'INCLDIRSTOMAKE': '/python-inst/include /python-inst/include '
-                   '/python-inst/include/python3.8 '
-                   '/python-inst/include/python3.8',
+                   '/python-inst/include/python3.9 '
+                   '/python-inst/include/python3.9',
  'INCLUDEDIR': '/python-inst/include',
- 'INCLUDEPY': '/python-inst/include/python3.8',
+ 'INCLUDEPY': '/python-inst/include/python3.9',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': '/usr/bin/ccache g++ -pthread -shared',
- 'LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
-            '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary',
+ 'LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
+            '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+            '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
+            '-flto=jobserver -fuse-linker-plugin -O2',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': '/usr/bin/ccache gcc '
-             '-I/tinderbox/buildslave/build/workdir/UnpackedTarball/expat/lib '
+             '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+             '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
              '-pthread -shared '
-             '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
-             '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary',
- 'LDVERSION': '3.8',
+             '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
+             '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+             '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
+             '-flto=jobserver -fuse-linker-plugin -O2',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/python-inst/lib/python3.8',
+ 'LIBDEST': '/python-inst/lib/python3.9',
  'LIBDIR': '/python-inst/lib',
- 'LIBFFI_INCLUDEDIR': '/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/include',
+ 'LIBFFI_INCLUDEDIR': '/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/python-inst/lib/pkgconfig',
- 'LIBPL': '/python-inst/lib/python3.8/config-3.8-x86_64-linux-gnu',
+ 'LIBPL': '/python-inst/lib/python3.9/config-3.9-x86_64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': '/usr/bin/ccache gcc '
-           '-I/tinderbox/buildslave/build/workdir/UnpackedTarball/expat/lib '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
            '-pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
@@ -572,20 +600,21 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/python-inst/lib/python3.8',
+ 'MACHDESTLIB': '/python-inst/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': '/usr/bin/ccache gcc '
-           '-I/tinderbox/buildslave/build/workdir/UnpackedTarball/expat/lib '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
            '-pthread',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
+ 'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/python-inst/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -598,7 +627,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
@@ -606,8 +635,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 0,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/tinderbox/buildslave/build/workdir/UnpackedTarball/openssl/include',
- 'OPENSSL_LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/openssl/lib',
+ 'OPENSSL_INCLUDES': '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include',
+ 'OPENSSL_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -g  -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
@@ -618,9 +647,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -636,41 +669,46 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  '
                              '-O3 -Wall -std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I./Include/internal -I. -I./Include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I./Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
-                    '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary',
+ 'PY_CORE_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
+                    '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+                    '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
+                    '-flto=jobserver -fuse-linker-plugin -O2',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/tinderbox/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
-               '-L/tinderbox/buildslave/build/workdir/LinkTarget/StaticLibrary',
+ 'PY_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/x86_64-pc-linux-gnu/.libs '
+               '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
+               '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
+               '-flto=jobserver -fuse-linker-plugin -O2',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 '
                         '-Wall -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I./Include/internal -I. -I./Include -fPIC',
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -679,10 +717,9 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tinderbox/buildslave/build/workdir/UnpackedTarball/python3',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/buildslave/build/workdir/UnpackedTarball/python3:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib',
  'SCRIPTDIR': '/python-inst/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
  'SHLIB_SUFFIX': '.so',
@@ -707,8 +744,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-3.8',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-3.9',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -721,20 +758,21 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tinderbox/buildslave/build/workdir/UnpackedTarball/python3 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/buildslave/build/workdir/UnpackedTarball/python3:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tinderbox/buildslave/build/workdir/UnpackedTarball/python3 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/buildslave/build/workdir/UnpackedTarball/python3:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib:/opt/rh/gcc-toolset-12/root/usr/lib64:/opt/rh/gcc-toolset-12/root/usr/lib '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.8',
+ 'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -746,8 +784,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tinderbox/buildslave/build/workdir/UnpackedTarball/python3',
- 'abs_srcdir': '/tinderbox/buildslave/build/workdir/UnpackedTarball/python3',
+ 'abs_builddir': '/home/buildslave/build/workdir/UnpackedTarball/python3',
+ 'abs_srcdir': '/home/buildslave/build/workdir/UnpackedTarball/python3',
  'datarootdir': '/python-inst/share',
  'exec_prefix': '/python-inst',
  'prefix': '/python-inst',
